use Test::More;

use_ok('App::TeleGramma');
use_ok('App::TeleGramma::Config');
use_ok('App::TeleGramma::PluginManager');
use_ok('App::TeleGramma::Plugin::Core::Fortune');
use_ok('App::TeleGramma::Plugin::Core::Stenographer');

done_testing();
